#
# Must define MAIN in file that includes this (e.g., = l1.ltx)

BASE := $(basename $(MAIN))
XFIGS := $(wildcard *.fig)
DIAFIGS := $(wildcard *.dia)
TEXFIGS := $(XFIGS:.fig=.tex)
EPSFIGS := $(XFIGS:.fig=.eps) $(DIAFIGS:.dia=.eps)
PDFFIGS := $(XFIGS:.fig=.pdf) $(DIAFIGS:.dia=.pdf)
TEXFILES := $(sort $(MAIN) $(wildcard *.tex) $(TEXFIGS))
STYFILES := mathrmletter.sty

JGRAPHS := $(wildcard *.j)
GGRAPHS := $(wildcard *.gnuplot)
EPSGRAPHS := $(JGRAPHS:.j=.eps) $(GGRAPHS:.gnuplot=.eps)
PDFGRAPHS := $(JGRAPHS:.j=.pdf) $(GGRAPHS:.gnuplot=.pdf)

IMAGES := $(wildcard figs/*.gif) $(wildcard figs/*.eps)
IMAGEFIGS := $(addsuffix .pdf, $(basename $(IMAGES)))
EXTRAFIGS := $(filter-out $(IMAGEFIGS), $(wildcard figs/*.pdf))
EXTRAFIGSRC := $(wildcard figs/*.odp) $(wildcard figs/*.ppt)

LATEX = pdflatex \\nonstopmode\\input
DVIPS = dvips -j0 -G0 -t letter
#PS2PDF = GS_OPTIONS=-sPAPERSIZE=letter ps2pdf -sPAPERSIZE=letter
PS2PDF = ps2pdf


all: $(BASE).pdf

#%.ps: %.dvi
#	$(DVIPS) $< -o $@
#%.pdf: %.ps
#	$(PS2PDF) $< $@

#%.ps: %.pdf
#	pdftops $< $@
%.pdf %.tex: %.fig
	fig2dev -L pdftex -p1 $< > $*.pdf
	fig2dev -L pdftex_t -p $*.pdf $< > $*.tex
#%.eps %.tex: %.fig
#	fig2dev -L pstex -p1 $< > $*.eps
#	fig2dev -L pstex_t -p $*.eps $< > $*.tex
%.eps: %.dia
	env DISPLAY= dia -n -e $@ $<
%.eps: %.j
	@rm -f $@~
	jgraph $< > $@~
	mv -f $@~ $@
%.eps: %.gnuplot %.data
	gnuplot $*.gnuplot
%.pdf: %.eps
	perl -ne 'exit 1 unless /\n/' $< \
		|| perl -p -i -e 's/\r/\n/g' $<
	epstopdf --outfile=$@ $<
figs/%.pdf: figs/%.gif
	convert $< $@

$(STYFILES):
	rm -f $@
	ln -s ../$@ .

RERUN = egrep -q '(^LaTeX Warning:|\(natbib\)).* Rerun'
UNDEFINED = egrep -q '^(LaTeX|Package natbib) Warning:.* undefined'

$(BASE).pdf: $(TEXFILES) $(STYFILES) $(PDFFIGS) $(PDFGRAPHS) \
		$(EXTRAFIGS) $(IMAGEFIGS)
	$(LATEX) $(MAIN) || ! rm -f $@
	! $(UNDEFINED) $(BASE).log || $(LATEX) $(MAIN) || ! rm -f $@
	! $(RERUN) $(BASE).log || $(LATEX) $(MAIN) || ! rm -f $@
	! $(RERUN) $(BASE).log || $(LATEX) $(MAIN) || ! rm -f $@
	touch $(BASE).dvi
	test ! -f .xpdf-running || xpdf -remote $(BASE)-server -reload

.SECONDARY: $(BASE).pdf $(PDFGRAPHS) $(PDFFIGS)

DIST = GNUmakefile $(TEXFILES) $(XFIGS) $(JGRAPHS) $(GGRAPHS) \
		$(IMAGES) $(EXTRAFIGS) $(EXTRAFIGSRC) $(STYFILES)
dist: $(BASE).tar.gz
$(BASE).tar.gz: $(DIST) ../Lecture.mk
	tar -chzf $@ -C .. Lecture.mk \
		$(patsubst %, $(notdir $(PWD))/%, $(DIST))

preview: $(BASE).pdf
	if test -f .xpdf-running; then			\
		xpdf -remote $(BASE)-server -quit;	\
		sleep 1;				\
	fi
	touch .xpdf-running
	(xpdf -remote $(BASE)-server -z 100 $(BASE).pdf; rm -f .xpdf-running) &

show: $(BASE).pdf
	xpdf -fullscreen $(BASE).pdf

osx: $(BASE).pdf
	open $(BASE).pdf

ignore:
	rm -f .gitignore
	for file in '*.aux' '*.bbl' '*.blg' '*.log' '*.dvi' '*.bak' '*.out' \
			PPRsimple.sty mathrmletter.sty .xpdf-running \
			$(BASE).tar.gz \
			$(TEXFIGS) $(EPSFIGS) $(PDFFIGS) $(IMAGEFIGS) \
			$(EPSGRAPHS) $(PDFGRAPHS) $(BASE).ps $(BASE).pdf; do \
		echo "$$file" >> .gitignore; \
	done
	git add .gitignore

DESTDIR=../../www/notes
install: $(BASE).pdf $(BASE).tar.gz
	cp $^ $(DESTDIR)/
	git add $(patsubst %, $(DESTDIR)/%, $^)

clean:
	rm -f $(BASE).ps $(BASE).pdf $(BASE).tar.gz
	rm -f $(TEXFIGS) $(EPSFIGS) $(PDFFIGS) $(EPSGRAPHS) \
		$(PDFGRAPHS) $(IMAGEFIGS)
	for sty in $(STYFILES); do \
		test ! -f ../$$sty || rm -f $$sty; \
	done
	rm -f *.dvi *.aux *.log *.bbl *.blg *.lof *.lot *.toc *.bak *.out
	rm -f *~ *.core core

always:
	@:

.PHONY: install clean all always ignore preview show osx dist
